Exec { timeout => 300 }

package{'nrpe':
    ensure => present,
    before => Class['nagios_configs']
}

file{'/etc/nagios/nrpe.cfg':
    ensure => 'present',
    mode => '0644',
    owner => 'nagios',
    group => 'nagios',
    require => Package['nrpe'],
}

class nagios_configs(){
    file_line{'allowed_hosts':
        path => '/etc/nagios/nrpe.cfg',
        match => 'allowed_hosts=',
        line => 'allowed_hosts=10.16.139.31',
    }

    # 5 minute load average
    file_line{'load5':
        path => '/etc/nagios/nrpe.cfg',
        match => 'command\[load5\]=',
        line => 'command[load5]=cut /proc/loadavg -f 1 -d " "',
    }

    # disk used on /var
    file_line{'df_var':
        path => '/etc/nagios/nrpe.cfg',
        match => "command\[df_var\]=",
        line => "command[df_var]=df /var/ | sed -re 's/.* ([0-9]+)%.*/\\1/' | grep -E '^[0-9]'",
    }
}
class{'nagios_configs':
    notify => Service['nrpe'],
}

service{'nrpe':
    ensure => running,
    enable => true,
    hasstatus => true,
}


# Create firewall rules to allow only the hosts that need to connect
# to nagios-nrpe

$hosts = [ '10.16.139.31' ]

define add_allow_host {
    $source = $title ? {
        'ALL' => '0.0.0.0/0',
        default => $title,
    }
    firewall { "001 nagios-nrpe incoming ${title}":
        proto  => 'tcp',
        dport  => [5666],
        action => 'accept',
        source => $source,
    }
}

add_allow_host {$hosts:}
