Exec { timeout => 300 }


# Ensure Firewall changes happen before libvirt service start
# preventing a clash with rules being set by libvirt
Firewall <| |> -> Class['nova::compute::libvirt']

if $::is_virtual_packstack == "true" {
    $libvirt_type = "qemu"
    nova_config{
        "DEFAULT/libvirt_cpu_mode": value => "none";
    }
}else{
    $libvirt_type = "kvm"
}

package{'python-cinderclient':
    before => Class["nova"]
}

nova_config{
    "DEFAULT/libvirt_inject_partition": value => "-1";
    "DEFAULT/volume_api_class": value => "nova.volume.cinder.API";
}

class {"nova::compute":
    enabled => true,
    vncproxy_host => "10.16.139.7",
    vncserver_proxyclient_address => "10.16.139.37",
}

exec { 'qemu-kvm':
    path => '/usr/bin',
    command => 'yum install -y qemu-kvm',
    before => Class['nova::compute::libvirt']
}

class { 'nova::compute::libvirt':
  libvirt_type                => "$libvirt_type",
  vncserver_listen            => "10.16.139.37",
}

exec {'load_kvm':
    user => 'root',
    command => '/bin/sh /etc/sysconfig/modules/kvm.modules',
    onlyif => '/usr/bin/test -e /etc/sysconfig/modules/kvm.modules',
}

Class['nova::compute']-> Exec["load_kvm"]

# Note : remove this once we're installing a version of openstack that isn't
#        supported on RHEL 6.3
if $::is_virtual_packstack == "true" and $::osfamily == "RedHat" and
    $::operatingsystemrelease == "6.3"{
    file { "/usr/bin/qemu-system-x86_64":
        ensure => link,
        target => "/usr/libexec/qemu-kvm",
        notify => Service["nova-compute"],
    }
}

# Tune the host with a virtual hosts profile
package {'tuned':
    ensure => present,
}

service {'tuned':
    ensure => running,
    require => Package['tuned'],
}

exec {'tuned-virtual-host':
    unless => '/usr/sbin/tuned-adm active | /bin/grep virtual-host',
    command => '/usr/sbin/tuned-adm profile virtual-host',
    require => Service['tuned'],
}

file_line { 'libvirt-guests':
    path  => '/etc/sysconfig/libvirt-guests',
    line  => 'ON_BOOT=ignore',
    match => '^[\s#]*ON_BOOT=.*',
    require => Class['nova::compute::libvirt']
}

# Remove libvirt's default network (usually virbr0) as it's unnecessary and can be confusing
exec {'virsh-net-destroy-default':
    onlyif  => '/usr/bin/virsh net-list | grep default',
    command => '/usr/bin/virsh net-destroy default',
    require => Package['libvirt'],
}

exec {'virsh-net-undefine-default':
    onlyif  => '/usr/bin/virsh net-list --inactive | grep default',
    command => '/usr/bin/virsh net-undefine default',
    require => Exec['virsh-net-destroy-default'],
}
package { 'glusterfs-fuse': ensure => present }
class { 'ceilometer':
    metering_secret => 'ceilometersecret',
    qpid_hostname   => '10.16.139.3',
    qpid_username  => 'guest',
    qpid_password  => 'guest',
    rpc_backend     => 'ceilometer.openstack.common.rpc.impl_qpid',
    verbose         => true,
    debug           => false
}

class { 'ceilometer::agent::auth':
    auth_url      => 'http://10.16.139.4:35357/v2.0',
    auth_password => 'badpass',
}

class { 'ceilometer::agent::compute':
}

# Create firewall rules to allow only the hosts that need to connect
# to nova compute

$hosts = [ '10.16.139.7' ]

define add_allow_host {
    $source = $title ? {
        'ALL' => '0.0.0.0/0',
        default => $title,
    }
    firewall { "001 nova compute incoming ${title}":
        proto  => 'tcp',
        dport  => ['5900-5999'],
        action => 'accept',
        source => $source,
    }
}

add_allow_host {$hosts:}



# Ensure Firewall changes happen before nova services start
# preventing a clash with rules being set by nova-compute and nova-network
Firewall <| |> -> Class['nova']

nova_config{
    "DEFAULT/sql_connection": value => "mysql://nova@10.16.139.2/nova";
    "DEFAULT/metadata_host": value => "10.16.139.7";
}

class { "nova":
    glance_api_servers => "10.16.139.5:9292",
    qpid_hostname => "10.16.139.3",
    qpid_username => 'guest',
    qpid_password => 'guest',
    rpc_backend => 'nova.openstack.common.rpc.impl_qpid',
    verbose     => true,
    debug       => true,
    qpid_port       => '5672',
    qpid_protocol   => 'tcp'
}


class {"nova::network::neutron":
  neutron_admin_password => "badpass",
  neutron_auth_strategy => "keystone",
  neutron_url => "http://10.16.139.8:9696",
  neutron_admin_tenant_name => "services",
  neutron_admin_auth_url => "http://10.16.139.4:35357/v2.0",
}

class {"nova::compute::neutron":
  libvirt_vif_driver => "nova.virt.libvirt.vif.LibvirtHybridOVSBridgeDriver",
}
